import {
  isSpecificationValid
} from "./chunk-XY5MZVO3.js";

// src/next/POST.tsx
import { getFrame } from "frames.js";
async function POST(req) {
  const body = await req.json();
  const isPostRedirect = req.nextUrl.searchParams.get("postType") === "post_redirect";
  const isTransactionRequest = req.nextUrl.searchParams.get("postType") === "tx";
  const postUrl = req.nextUrl.searchParams.get("postUrl");
  const specification = req.nextUrl.searchParams.get("specification") ?? "farcaster";
  if (!postUrl) {
    return Response.error();
  }
  if (!isSpecificationValid(specification)) {
    return Response.json({ message: "Invalid specification" }, { status: 400 });
  }
  try {
    const r = await fetch(postUrl, {
      method: "POST",
      headers: {
        Accept: "application/json",
        "Content-Type": "application/json"
      },
      redirect: isPostRedirect ? "manual" : void 0,
      body: JSON.stringify(body)
    });
    if (r.status === 302) {
      return Response.json(
        {
          location: r.headers.get("location")
        },
        { status: 302 }
      );
    }
    if (r.status >= 400 && r.status < 500) {
      const json = await r.json();
      if ("message" in json) {
        return Response.json({ message: json.message }, { status: r.status });
      }
    }
    if (isTransactionRequest) {
      const transaction = await r.json();
      return Response.json(transaction);
    }
    const htmlString = await r.text();
    const result = getFrame({
      htmlString,
      url: body.untrustedData.url,
      specification
    });
    return Response.json(result);
  } catch (err) {
    console.error(err);
    return Response.error();
  }
}

export {
  POST
};
